@@ -1,11 +1,12 @@
 """Graphite AWS cleaner
 
 Usage:
-  graphite-aws-cleaner --pattern <pattern> --storage-dir=<graphite_storage_directory> [--loglevel=<loglevel>]
+  graphite-aws-cleaner --pattern <pattern> --storage-dir=<graphite_storage_directory> [--dry-run] [--loglevel=<loglevel>]
 
 Options:
   -p --pattern=<pattern>    specify instance name pattern to look for
   -d --storage-dir=<dir>    specify graphite storage directory
+  -n --dry-run              do not remove directories, only outputs information
   -l --loglevel=<loglevel>  specify log level [default: INFO]
   -h --help                 show this
   -v --version              shows version
@@ -19,7 +20,9 @@ from docopt import docopt
 from . import (
     __version__,
     remove_hosts_from_graphite,
-    get_running_instances_hostnames)
+    get_running_instances_hostnames,
+    noop_remove,
+)
 
 
 def main():
@@ -27,6 +30,7 @@ def main():
     loglevel = arguments['--loglevel']
     name_pattern = arguments['--pattern']
     storage_dir = arguments['--storage-dir']
+    dry_run = arguments['--dry-run']
 
     logger = logging.getLogger('graphite_cleaner')
     logger.setLevel(getattr(logging, loglevel))
@@ -37,4 +41,7 @@ def main():
     logger.addHandler(ch)
 
     hostnames = get_running_instances_hostnames(name_pattern)
-    remove_hosts_from_graphite(storage_dir, name_pattern, hostnames)
\ No newline at end of file
+    if dry_run:
+        remove_hosts_from_graphite(storage_dir, name_pattern, hostnames, noop_remove)
+    else:
+        remove_hosts_from_graphite(storage_dir, name_pattern, hostnames)
\ No newline at end of file
